function pontforce()

%Pontoon dimensions. Treat like a rectangular box
B = 28;         %breadth
L = 68;         %length
d = 10.5;       %draught
f = 5;          %width of flange

z = -d;         %z-coordinate at bottom of pontoon
zm = z/2;       %z-middle coordinate
g = 9.81;       %acceleration of gravity    
rho = 1025;     %density of seawater 

state = 3;      %1=1yr storm, 2=10yr storm, 3=100yr storm

%call functions jonswap and addedmass to get variables
[~, ~, ~, om, ~, n, A_n] = jonswap;
[Ma_heave, ~, Ma_sway] = addedmass;

%Determine the phase shift for each pair of pontoons.
dist = [0,9.28,25.81,50.575,83.525,124.613,173.77,230.91,295.95,360];
n_phi = length(dist);
wave_L = g*2*pi./(om.^2);
phi = zeros(n,n_phi);

for i = 1:n_phi
    for r = 1:n
        phi(r,i) = 2*pi*dist(i)/wave_L(r);
    end
end

dt = 0.2;
tmax = 1*60*60;
t = 0:dt:tmax;
nt = length(t);
F_fkh = zeros(nt,n_phi);
F_dh = zeros(nt,n_phi);

F_fks = zeros(nt,n_phi);
F_ds = zeros(nt,n_phi);

F_fkr = zeros(nt,n_phi);
F_dr = zeros(nt,n_phi);

%Create random phase angle for each wvae component. The shuffle command 
%makes sure the same numbers are not repeated after MATLAB restarts
rng('shuffle');
eps = rand(n,1)*2*pi;


for ti = 1:nt
for phase = 1:n_phi
   for j = 1:n
       k = (om(j)^2)/g;
              
       %%% HEAVE FORCES %%%
       %FROUDE-KRILOFF
       F_fkh(ti,phase) =  F_fkh(ti,phase) + ...
           rho*g*A_n(j,state)*exp(k*z)*(B+2*f)*(2/k)*...
           sin(k*(2*f+L)/2)*sin(om(j)*t(ti)+eps(j)+phi(j,phase));
       
       %DIFFRACTION
       F_dh(ti,phase) = F_dh(ti,phase) + ...
           (Ma_heave(j)/(2*f+L))*(-(om(j))^2)*A_n(j,state)*exp(k*zm)*...
           (2/k)*sin(k*(2*f+L)/2)*sin(om(j)*t(ti)+eps(j)+phi(j,phase));
       
       %%% SWAY FORCES %%%
       %FROUDE-KRILOFF - forces on both edges
       F_fks(ti,phase) = F_fks(ti,phase) + ...
           rho*g*A_n(j,state)*B*((1-exp(z*k))/k)*...
           sin(om(j)*t(ti)+eps(j)-k*(-L/2)+phi(j,phase)) - ... force on first edge
           rho*g*A_n(j,state)*B*((1-exp(z*k))/k)*sin(om(j)*t(ti)+ ...
           eps(j)-k*(L/2)+phi(j,phase)) ;
       
       %DIFFRACTION FORCE
       F_ds(ti,phase) = F_ds(ti,phase) + ...
           (om(j))^2*A_n(j,state)*(Ma_sway(j)/d)*((1-exp(z*k))/k)*...
           cos(om(j)*t(ti)-k*(0)+eps(j)+phi(j,phase)); %x_mid=0
       
       %%% ROLL MOMENTS %%%
       
       %FROUDE KRILOFF MOMENT
       F_fkr(ti,phase) = F_fkr(ti,phase)+ ...
           rho*g*A_n(j,state)*exp(k*z)*(B+2*f)*...
           (cos(om(j)*t(ti)+eps(j)+phi(j,phase))*...
           (k*(2*f+L)*cos(k*(2*f+L)/2)-2*sin(k*(2*f+L)/2))/(k^2));
       %DIFFRACTION MOMENT
       F_dr(ti,phase) = F_dr(ti,phase)+ ...
           (Ma_heave(j)/(2*f+L))*(-(om(j))^2)*A_n(j,state)*exp(k*zm)*...
           (cos(om(j)*t(ti)+eps(j)+phi(j,phase))*...
           (k*(2*f+L)*cos(k*(2*f+L)/2)-2*sin(k*(2*f+L)/2))/(k^2));
   end
end
end

F_heave =F_fkh+F_dh;
F_sway = F_fks+F_ds;
F_roll = F_fkr+F_dr;

%must be run on computer with excel for windows to create file correctly
xlswrite('seastate100yr3_1hr.xlsx', F_heave,1) 
xlswrite('seastate100yr3_1hr.xlsx', F_sway,2)
xlswrite('seastate100yr3_1hr.xlsx', F_roll,3)

% figure
% subplot(3,3,1), hold on
% plot(t,F_fkh(:,1))
% plot(t,F_fkh(:,2))
% plot(t,F_fkh(:,3))
% legend('1','2','3')
% title('Froude-Krylov forces, heave')
% subplot(3,3,2), hold on
% plot(t,F_dh(:,1))
% plot(t,F_dh(:,2))
% plot(t,F_dh(:,3))
% title('Diffraction forces, heave')
% subplot(3,3,3), hold on
% plot(t,F_heave(:,1))
% plot(t,F_heave(:,2))
% plot(t,F_heave(:,3))
% title('Total heave forces')
% subplot(3,3,4), hold on
% plot(t,F_fks(:,1))
% plot(t,F_fks(:,2))
% plot(t,F_fks(:,3))
% title('Froude-Krylov forces, sway')
% subplot(3,3,5), hold on
% plot(t,F_ds(:,1))
% plot(t,F_ds(:,2))
% plot(t,F_ds(:,3))
% title('Diffraction forces, sway')
% subplot(3,3,6), hold on
% plot(t,F_sway(:,1))
% plot(t,F_sway(:,2))
% plot(t,F_sway(:,3))
% title('Total sway forces')
% subplot(3,3,7), hold on
% plot(t,F_fkr(:,1))
% plot(t,F_fkr(:,2))
% plot(t,F_fkr(:,3))
% title('Froude-Krylov moment, roll')
% subplot(3,3,8), hold on
% plot(t,F_dr(:,1))
% plot(t,F_dr(:,2))
% plot(t,F_dr(:,3))
% title('Diffraction moment, roll')
% subplot(3,3,9), hold on
% plot(t,F_roll(:,1))
% plot(t,F_roll(:,2))
% plot(t,F_roll(:,3))
% title('Total roll moment')

%  figure
% % plot(t,F_fk(:,1)),hold on
% % plot(t,F_fk(:,2)),hold on
%  plot(t,F_fkh(:,3))
%  grid on
% % title('Froude-Kriloff force in heave over time')
%  figure
% % plot(t,F_d(:,1)), hold on
% % plot(t,F_d(:,2)), hold on
%  plot(t,F_dh(:,3))
%  grid on
% figure
% %plot(t,F(:,1)), hold on
% %plot(t,F(:,2)), hold on
% plot(t,F_heave(:,3))
% legend('1-year state');%,'50-year state','100-year state')
% grid on
%plot(t,F_fks(:,1))
end